# Demo examples
    
## default
This is a 3-sector one-region model.
It contains a residential, conversion, and gas supply sectors.
The time framework covers 2020-2050.
It uses 6 timeslices.

## default_timeslice
This is developed from the default model. 
Timesliced technodata are given for the power sector.

## medium
This is developed from the default model. 
Demand for cooking is added in the residential sector.

## multiple_agents
This is developed from the default model.
Two agents, each one assigned half of the heat demand, are modelled.

## minimum_service
This is a one-sector one-region model.
It models an industry sector with a minimum service constraint.
The time framework covers 2020-2050.
It uses 6 timeslices.

## trade
This is a 3-sector two-region model.
It contains a residential, conversion, and gas supply sectors.
The regions can trade gas and electricity.
The time framework covers 2020-2035.
It uses 6 timeslices.



